@@ -42,15 +42,6 @@ def authenticated_post(url, data=None, json=None, headers={}):
     return response
 
 
-def kraken_get(url, params={}, headers={}):
-    """
-    Add accept header required by kraken API v5.
-    see: https://discuss.dev.twitch.tv/t/change-in-access-to-deprecated-kraken-twitch-apis/22241
-    """
-    headers["Accept"] = "application/vnd.twitchtv.v5+json"
-    return authenticated_get(url, params, headers)
-
-
 def gql_post(query):
     url = "https://gql.twitch.tv/gql"
     response = authenticated_post(url, data=query).json()
@@ -71,15 +62,6 @@ def gql_query(query):
     return response
 
 
-def get_video_legacy(video_id):
-    """
-    https://dev.twitch.tv/docs/v5/reference/videos#get-video
-    """
-    url = "https://api.twitch.tv/kraken/videos/{}".format(video_id)
-
-    return kraken_get(url).json()
-
-
 VIDEO_FIELDS = """
     id
     title
@@ -96,6 +78,30 @@ VIDEO_FIELDS = """
 """
 
 
+CLIP_FIELDS = """
+    id
+    slug
+    title
+    createdAt
+    viewCount
+    durationSeconds
+    url
+    videoQualities {
+        frameRate
+        quality
+        sourceURL
+    }
+    game {
+        id
+        name
+    }
+    broadcaster {
+        displayName
+        login
+    }
+"""
+
+
 def get_video(video_id):
     query = """
     {{
@@ -115,31 +121,12 @@ def get_clip(slug):
     query = """
     {{
         clip(slug: "{}") {{
-            id
-            slug
-            title
-            createdAt
-            viewCount
-            durationSeconds
-            url
-            videoQualities {{
-                frameRate
-                quality
-                sourceURL
-            }}
-            game {{
-                id
-                name
-            }}
-            broadcaster {{
-                displayName
-                login
-            }}
+            {fields}
         }}
     }}
     """
 
-    response = gql_query(query.format(slug))
+    response = gql_query(query.format(slug, fields=CLIP_FIELDS))
     return response["data"]["clip"]
 
 
@@ -184,26 +171,7 @@ def get_channel_clips(channel_id, period, limit, after=None):
           edges {{
             cursor
             node {{
-              id
-              slug
-              title
-              createdAt
-              viewCount
-              durationSeconds
-              url
-              videoQualities {{
-                frameRate
-                quality
-                sourceURL
-              }}
-              game {{
-                id
-                name
-              }}
-              broadcaster {{
-                displayName
-                login
-              }}
+              {fields}
             }}
           }}
         }}
@@ -211,12 +179,13 @@ def get_channel_clips(channel_id, period, limit, after=None):
     }}
     """
 
-    query = query.format(**{
-        "channel_id": channel_id,
-        "after": after if after else "",
-        "limit": limit,
-        "period": period.upper(),
-    })
+    query = query.format(
+        channel_id=channel_id,
+        after=after if after else "",
+        limit=limit,
+        period=period.upper(),
+        fields=CLIP_FIELDS
+    )
 
     response = gql_query(query)
     user = response["data"]["user"]
@@ -264,18 +233,7 @@ def get_channel_videos(channel_id, limit, sort, type="archive", game_ids=[], aft
                 edges {{
                     cursor
                     node {{
-                        id
-                        title
-                        publishedAt
-                        broadcastType
-                        lengthSeconds
-                        game {{
-                            name
-                        }}
-                        creator {{
-                            login
-                            displayName
-                        }}
+                        {fields}
                     }}
                 }}
             }}
@@ -283,14 +241,15 @@ def get_channel_videos(channel_id, limit, sort, type="archive", game_ids=[], aft
     }}
     """
 
-    query = query.format(**{
-        "channel_id": channel_id,
-        "game_ids": game_ids,
-        "after": after if after else "",
-        "limit": limit,
-        "sort": sort.upper(),
-        "type": type.upper(),
-    })
+    query = query.format(
+        channel_id=channel_id,
+        game_ids=game_ids,
+        after=after if after else "",
+        limit=limit,
+        sort=sort.upper(),
+        type=type.upper(),
+        fields=VIDEO_FIELDS
+    )
 
     response = gql_query(query)
 
